
library(rstan)
library(loo)
library(dplyr)
library(ggplot2)

rstan_options(auto_write = TRUE)
options(mc.cores = parallel::detectCores())

# read data ----------------------------------------------------------------
d_coo <- read.csv("data_coo.csv", header = T)
d_vs <- read.csv("data_vs.csv", header = T)
d_prox <- read.csv("data_prox.csv", header = T)


# prox --------------------------------------------------------------------

data_prox <- 
  list(N = nrow(d_prox), 
       N_iid = length(unique(d_prox$focal_id)), 
       N_tid = length(unique(d_prox$trial_id)), 
       Time = d_prox$time, 
       Group = d_prox$group,
       Sex = d_prox$sex, 
       Diet = d_prox$diet,
       C_S = d_prox$mgm, 
       IID = d_prox$focal_id, 
       TID = d_prox$trial_id,
       Gs = d_prox$gs)

# standardization of explanatory variables
data_prox$Time <- scale(data_prox$Time)[, 1]
data_prox$Group <- scale(data_prox$Group)[, 1]
data_prox$Sex <- scale(data_prox$Sex)[, 1]
data_prox$Diet <- scale(data_prox$Diet)[, 1]

# compile & MCMC
stanmodel_prox <- stan_model(file = "code_prox.stan")

fit_prox <- 
  sampling(stanmodel_prox, 
           data = data_prox, 
           iter = 10500, 
           chains = 4, 
           warmup = 500, 
           seed = 123, 
           control = list(adapt_delta = 0.99))

summary(fit_prox)$summary


# calculcate WAIC
waic_prox <- waic(extract_log_lik(fit_prox))
waic_prox


# coo ---------------------------------------------------------------------

data_coo <- 
  list(N = nrow(d_coo), 
       N_iid = length(unique(d_coo$focal_id)), 
       N_tid = length(unique(d_coo$trial_id)), 
       Time = d_coo$time, 
       Group = d_coo$group, 
       Sex = d_coo$sex, 
       Diet = d_coo$diet, 
       M = d_coo$n, 
       Coo = d_coo$coo, 
       IID = d_coo$focal_id, 
       TID = d_coo$trial_id)

# standardization of explanatory variables
data_coo$Time <- scale(data_coo$Time)[, 1]
data_coo$Group <- scale(data_coo$Group)[, 1]
data_coo$Sex <- scale(data_coo$Sex)[, 1]
data_coo$Diet <- scale(data_coo$Diet)[, 1]

# compile & MCMC
stanmodel_coo <- stan_model(file = "code_coo.stan")

fit_coo <- sampling(stanmodel_coo, 
                    data = data_coo, 
                    iter = 10500, 
                    chains = 4, 
                    warmup = 500, 
                    seed = 123, 
                    control = list(adapt_delta = 0.99))

summary(fit_coo)$summary

# calcluate WAIC
waic_coo <- waic(extract_log_lik(fit_coo))
waic_coo

# visual scanning --------------------------------------------------------------

# logit function
logit <- function(x){
  return(log(x/(1-x)))
}

data_vs <- 
  list(N = nrow(d_vs), 
       N_iid = length(unique(d_vs$focal_id)), 
       N_tid = length(unique(d_vs$trial_id)), 
       Time = d_vs$time, 
       Group = d_vs$group, 
       Sex = d_vs$sex, 
       Diet = d_vs$diet, 
       M = d_vs$n, 
       Vs = d_vs$vs, 
       IID = d_vs$focal_id, 
       TID = d_vs$trial_id, 
       sigma_q = logit(0.9999))

# standardization of explanatory variables
data_vs$Time <- scale(data_vs$Time)[, 1]
data_vs$Group <- scale(data_vs$Group)[, 1]
data_vs$Sex <- scale(data_vs$Sex)[, 1]
data_vs$Diet <- scale(data_vs$Diet)[, 1]

# compile & MCMC
stanmodel_vs <- stan_model(file = "code_vs.stan")

fit_vs <- sampling(stanmodel_vs, 
                    data = data_vs, 
                    iter = 10500, 
                    chains = 4, 
                    warmup = 500, 
                    seed = 123, 
                    control = list(adapt_delta = 0.99))

summary(fit_vs)$summary

# calculate WAIC
waic_vs <- waic(extract_log_lik(fit_vs))
waic_vs

